# -*- coding: utf-8 -*-
# Generated by Django 1.11.12 on 2018-08-06 15:28
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('orchestra', '0078_todoqa'),
    ]

    operations = [
        migrations.AlterField(
            model_name='project',
            name='status',
            field=models.IntegerField(choices=[(0, 'Active'), (2, 'Aborted'), (3, 'Paused')], default=0),
        ),
    ]
