Hello!  This email was in response to your request for an Orchestra password reset.  To reset the password, please visit this URL:

<a rel="noreferrer" href="{{ protocol }}://{{ domain }}{% url 'auth_password_reset_confirm' uidb64=uid token=token %}">
  {{ protocol }}://{{ domain }}{% url 'auth_password_reset_confirm' uidb64=uid token=token %}
</a>
