{% extends 'orchestra/base.html' %}
{% load staticfiles %}

{% block title %}Activate{% endblock %}

{% block main %}
<div>
  Account activation with key {{ activation_key }} has failed.
</div>
{% endblock %}
