# -*- coding: utf-8 -*-
# Generated by Django 1.9.5 on 2016-04-27 17:43
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('orchestra', '0047_auto_20160427_1412'),
        ('orchestra', '0047_worker_phone'),
    ]

    operations = [
    ]
