# -*- coding: utf-8 -*-
# Generated by Django 1.9.5 on 2016-05-04 17:31
from __future__ import unicode_literals

import jsonfield.fields
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('orchestra', '0058_staffingrequest_required_role'),
    ]

    operations = [
        migrations.AddField(
            model_name='step',
            name='detailed_description_function',
            field=jsonfield.fields.JSONField(default={}),
        ),
    ]
