# -*- coding: utf-8 -*-
# Generated by Django 1.9.6 on 2016-08-04 02:00
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('orchestra', '0065_auto_20160802_0301'),
    ]

    operations = [
        migrations.AlterUniqueTogether(  # manually-reviewed
            name='taskassignment',
            unique_together=set([]),
        ),
    ]
